library (qgraph)
library (igraph)

#########################
#Construction of networks

input1 <- matrix (1, 3, 3)

input2 <- matrix (0, 6, 6)
input2 [1,2] <- 1
input2 [1,3] <- 1
input2 [1,4] <- 1
input2 [2,3] <- 1
input2 [4,5] <- 1
input2 [4,6] <- 1
input2 [5,6] <- 1

input3 <- matrix (0, 9, 9)
input3 [1,2] <- 1
input3 [1,3] <- 1
input3 [1,4] <- 1
input3 [2,3] <- 1
input3 [4,5] <- 1
input3 [4,6] <- 1
input3 [5,6] <- 1
input3 [2,7] <- 1
input3 [3,7] <- 1
input3 [7,8] <- 1
input3 [7,9] <- 1
input3 [8,9] <- 1

input4 <- matrix (0, 14, 14)
input4 [1,2] <- 1
input4 [1,3] <- 1
input4 [1,4] <- 1
input4 [2,3] <- 1
input4 [4,5] <- 1
input4 [4,6] <- 1
input4 [5,6] <- 1
input4 [2,7] <- 1
input4 [3,7] <- 1
input4 [7,8] <- 1
input4 [7,9] <- 1
input4 [8,9] <- 1
input4 [7,10] <- 1
input4 [10,11] <- 1
input4 [10,12] <- 1
input4 [11,12] <- 1
input4 [1,13] <- 1
input4 [7,14] <- 1
input4 [13,14] <- 1

layout <- qgraph (input4, directed = FALSE, DoNotPlot = TRUE) $ layout

#########################
#Plotting

pdf ('Bob.pdf', 3, 3)
par (mfrow = c (2, 2))

qgraph (input1, layout = layout, title = '(a)', labels = c ('cares', 'moral', 'honest', rep ('', 11)), color = 'red', vsize = 12, 
        label.scale = FALSE, label.cex = .36, edge.width = 2)
qgraph (input2, directed = FALSE, title = '(b)', labels = c ('cares', 'moral', 'honest', 'leader', 'intelligent', 'competent'), 
        color = c (rep ('red', 3), rep ('lightblue', 3)), vsize = 12, label.scale = FALSE, label.cex = .36, edge.width = 2)
qgraph (input3, directed = FALSE, title = '(c)', 
        labels = c ('cares', 'moral', 'honest', 'leader', 'intelligent', 'competent', 'hope', 'proud', 'sympathy'),
        color = c (rep ('red', 3), rep ('lightblue', 3), rep ('green', 3)), vsize = 12, label.scale = FALSE, label.cex = .36, 
        edge.width = 2)
qgraph (input4, directed = FALSE, title = '(d)',
        labels = c ('cares', 'moral', 'honest', 'leader', 'intelligent', 'competent', 'hope', 'proud', 'sympathy', 'sticker', 'convince',
                    'vote', 'good', 'like'), 
        color = c (rep ('red', 3), rep ('lightblue', 3), rep ('green', 3), rep ('yellow', 3), rep ('pink', 2)), vsize = 12, 
        label.scale = FALSE, label.cex = .36, edge.width = 2)


dev.off ()

#########################
#Small-world calculations

SW_Index <- function (Graph, ci = c (.1, .05, .01, .001))
{
  randomC <- vector (, 1000)
  randomL <- vector (, 1000)
  for (i in 1:1000)
  {
    Rgraph <- erdos.renyi.game (vcount (Graph), ecount (Graph), 'gnm')
    randomC [i] <- transitivity (Rgraph, 'average')
    randomL [i] <- average.path.length(Rgraph)
  }
  MrandomC <- mean (randomC)
  MrandomL <- mean (randomL)
  Clustering.Graph = transitivity (Graph, 'average')
  ASPL.Graph = average.path.length (Graph)
  Index <- (Clustering.Graph / MrandomC) / (ASPL.Graph / MrandomL)
  
  sm_sample <- vector (, 1000)
  for (i in 1:1000)
  {
    Rgraph <- erdos.renyi.game (vcount (Graph), ecount (Graph), 'gnm')
    sm_sample [i] <- (transitivity (Rgraph, 'average') / MrandomC) /(average.path.length(Rgraph) / MrandomL)
  }
  CI <- as.vector (((quantile (sm_sample, 1 - (ci / 2)) - quantile (sm_sample, ci / 2)) / 2) + 1)
  return (list (SW.Index = Index, Upper.CI = data.frame (CI = ci, Value.CI = CI), 
                Clustering.Graph = Clustering.Graph, Clustering.Random.Graph = MrandomC,
                ASPL.Graph = ASPL.Graph, ASPL.Random.Graph = MrandomL))
}


Graph <- qgraph (input4, layout = 'spring')

iGraph <- graph.adjacency (input4, "undirected", diag = FALSE, weighted = TRUE)

SW_Index (iGraph)

Graph <- qgraph (input4, directed = FALSE, title = 'd',
                 labels = c ('cares', 'moral', 'honest', 'leader', 'intelligent', 'competent', 'hope', 'proud', 'sympathy', 'sticker', 'convince',
                             'vote', 'good', 'like'), 
                 color = c (rep ('red', 3), rep ('lightblue', 3), rep ('green', 3), rep ('yellow', 3), rep ('pink', 2)))

centrality (Graph)

